@@ -5,6 +5,7 @@ import string
 import time
 import traceback
 import uuid
+from copy import deepcopy
 from functools import reduce
 from itertools import groupby
 from typing import List, Dict, Union
@@ -14,6 +15,22 @@ from importlib.util import spec_from_file_location, module_from_spec
 from lesscode_utils.encryption_algorithm import MD5
 
 
+def convert(value, func):
+    return func(value)
+
+
+def get_value_from_dict(data: dict, key: str = None):
+    value = deepcopy(data)
+    if key:
+        key_list = key.split(".")
+        for k in key_list:
+            if not isinstance(value, dict):
+                break
+            else:
+                value = value.get(k)
+    return value
+
+
 def list_dict_group(data: List[Dict], key):
     """
     列表字典去重
